@@ -1,10 +1,10 @@
 package Code::TidyAll::CacheModel;
 
 use Digest::SHA qw(sha1_hex);
-use File::Slurp::Tiny qw(read_file);
+use Path::Tiny ();
 use Moo;
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 # todo, type checking?
 
@@ -19,7 +19,7 @@ has 'path'          => ( is => 'ro', required => 1 );
 
 sub _build_file_contents {
     my ($self) = @_;
-    return read_file( $self->full_path );
+    return Path::Tiny::path( $self->full_path )->slurp;
 }
 
 sub _trigger_file_contents {
@@ -86,7 +86,7 @@ Code::TidyAll::CacheModel - Caching model for Code::TidyAll
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -172,7 +172,7 @@ Attempts to remove the value from the cache
 
 =head1 SUPPORT
 
-bugs may be submitted through
+Bugs may be submitted through
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
@@ -191,7 +191,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
