@@ -3,15 +3,14 @@ package Code::TidyAll::Git::Precommit;
 use Capture::Tiny qw(capture_stdout capture_stderr);
 use Code::TidyAll;
 use Code::TidyAll::Git::Util qw(git_files_to_commit);
-use Cwd qw(cwd);
-use File::Slurp::Tiny qw(write_file);
 use Guard;
 use Log::Any qw($log);
 use IPC::System::Simple qw(capturex run);
 use Moo;
+use Path::Tiny qw(path);
 use Try::Tiny;
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 # Public
 has 'conf_name'       => ( is => 'ro' );
@@ -33,9 +32,11 @@ sub check {
         # Find conf file at git root
         my $root_dir = capturex( $self->git_path, "rev-parse", "--show-toplevel" );
         chomp($root_dir);
+        $root_dir = path($root_dir);
+
         my @conf_names
             = $self->conf_name ? ( $self->conf_name ) : Code::TidyAll->default_conf_names;
-        my ($conf_file) = grep {-f} map { join( "/", $root_dir, $_ ) } @conf_names
+        my ($conf_file) = grep { $_->is_file } map { $root_dir->child($_) } @conf_names
             or die sprintf( "could not find conf file %s", join( " or ", @conf_names ) );
 
         # Store the stash, and restore it upon exiting this scope
@@ -88,7 +89,7 @@ tidyall'd
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -230,7 +231,7 @@ a remote shared repository.
 
 =head1 SUPPORT
 
-bugs may be submitted through
+Bugs may be submitted through
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
@@ -249,7 +250,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
