@@ -1,7 +1,6 @@
 package Code::TidyAll::Plugin;
 
 use Code::TidyAll::Util::Zglob qw(zglobs_to_regex);
-use File::Slurp::Tiny qw(read_file write_file);
 use File::Which qw( which );
 use IPC::Run3 qw( run3 );
 use Scalar::Util qw(weaken);
@@ -9,7 +8,7 @@ use Text::Diff 1.44 qw( diff );
 
 use Moo;
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 # External
 has 'argv'               => ( is => 'ro', default => q{} );
@@ -129,7 +128,7 @@ sub postprocess_source {
 }
 
 sub process_source_or_file {
-    my ( $self, $orig_source, $basename, $check_only ) = @_;
+    my ( $self, $orig_source, $rel_path, $check_only ) = @_;
 
     my $new_source = $orig_source;
     if ( $self->can('transform_source') ) {
@@ -138,23 +137,23 @@ sub process_source_or_file {
         }
     }
     if ( $self->can('transform_file') ) {
-        my $tempfile = $self->_write_temp_file( $basename, $new_source );
+        my $tempfile = $self->_write_temp_file( $rel_path, $new_source );
         foreach my $iter ( 1 .. $self->tidyall->iterations ) {
             $self->transform_file($tempfile);
         }
-        $new_source = read_file($tempfile);
+        $new_source = $tempfile->slurp;
     }
     if ( $self->can('validate_source') ) {
         $self->validate_source($new_source);
     }
     if ( $self->can('validate_file') ) {
-        my $tempfile = $self->_write_temp_file( $basename, $new_source );
+        my $tempfile = $self->_write_temp_file( $rel_path, $new_source );
         $self->validate_file($tempfile);
     }
 
     my $diff;
     if ( $check_only && $new_source ne $orig_source ) {
-        $diff = $self->_maybe_diff( $orig_source, $new_source, $basename );
+        $diff = $self->_maybe_diff( $orig_source, $new_source, $rel_path );
     }
 
     return ( $new_source, $diff );
@@ -167,19 +166,20 @@ sub _maybe_diff {
 
     my $orig     = shift;
     my $new      = shift;
-    my $basename = shift;
+    my $rel_path = shift;
 
-    my $orig_file = $self->_write_temp_file( $basename . '.orig', $orig );
-    my $new_file  = $self->_write_temp_file( $basename . '.new',  $new );
+    my $orig_file = $self->_write_temp_file( $rel_path . '.orig', $orig );
+    my $new_file  = $self->_write_temp_file( $rel_path . '.new',  $new );
 
-    return diff( $orig_file, $new_file, { Style => 'Unified' } );
+    return diff( $orig_file->stringify, $new_file->stringify, { Style => 'Unified' } );
 }
 
 sub _write_temp_file {
-    my ( $self, $basename, $source ) = @_;
+    my ( $self, $rel_path, $source ) = @_;
 
-    my $tempfile = join( "/", $self->tidyall->_tempdir(), $basename );
-    write_file( $tempfile, $source );
+    my $tempfile = $self->tidyall->_tempdir->child($rel_path);
+    $tempfile->parent->mkpath( { mode => 0755 } );
+    $tempfile->spew($source);
     return $tempfile;
 }
 
@@ -204,7 +204,7 @@ Code::TidyAll::Plugin - Create plugins for tidying or validating code
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -364,7 +364,7 @@ error. This runs on all plugins I<after> any of the other methods.
 
 =head1 SUPPORT
 
-bugs may be submitted through
+Bugs may be submitted through
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
@@ -383,7 +383,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
