@@ -1,12 +1,11 @@
 package Code::TidyAll::Plugin::JSBeautify;
 
-use File::Slurp::Tiny qw(write_file);
 use IPC::Run3 qw(run3);
 use Moo;
 use Try::Tiny;
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 sub _build_cmd {'js-beautify'}
 
@@ -19,7 +18,7 @@ sub transform_file {
         my $output;
         my $exit = run3( $cmd, \undef, \$output, \$output );
         die "exited with $?\n" if $?;
-        write_file( $file, $output );
+        $file->spew($output);
     }
     catch {
         die sprintf(
@@ -45,7 +44,7 @@ Code::TidyAll::Plugin::JSBeautify - Use js-beautify with tidyall
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -83,7 +82,7 @@ Full path to js-beautify
 
 =head1 SUPPORT
 
-bugs may be submitted through
+Bugs may be submitted through
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
@@ -102,7 +101,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
