@@ -1,44 +1,27 @@
 package Code::TidyAll::Plugin::JSHint;
 
 use Code::TidyAll::Util qw(tempdir_simple);
-use File::Slurp::Tiny qw(write_file);
 use IPC::Run3 qw(run3);
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.49';
+has 'options' => ( is => 'ro', predicate => '_has_options' );
 
-sub validate_params {
-    my ( $self, $params ) = @_;
+with 'Code::TidyAll::Role::Tempdir';
 
-    delete( $params->{options} );
-    return $self->SUPER::validate_params($params);
-}
+our $VERSION = '0.50';
 
 sub _build_cmd {'jshint'}
 
-around BUILDARGS => sub {
-    my $orig  = shift;
-    my $class = shift;
-
-    my $args = $class->$orig(@_);
-
-    if ( my $options_string = delete $args->{options} ) {
-        my @options   = split( /\s+/, $options_string );
-        my $conf_dir  = tempdir_simple();
-        my $conf_file = "$conf_dir/jshint.json";
-        write_file( $conf_file, '{ ' . join( ",\n", map {"\"$_\": true"} @options ) . ' }' );
-        $args->{argv} ||= "";
-        $args->{argv} .= " --config $conf_file";
-    }
-
-    return $args;
-};
-
 sub validate_file {
     my ( $self, $file ) = @_;
 
-    my $cmd = sprintf( "%s %s %s", $self->cmd, $self->argv, $file );
+    my $argv = $self->argv || q{};
+    if ( $self->_has_options ) {
+        $argv .= q{ } . $self->_config_file_argv;
+    }
+
+    my $cmd = sprintf( "%s %s %s", $self->cmd, $argv, $file );
     my $output;
     run3( $cmd, \undef, \$output, \$output );
     if ( $output =~ /\S/ ) {
@@ -47,6 +30,15 @@ sub validate_file {
     }
 }
 
+sub _config_file_argv {
+    my $self = shift;
+
+    my $conf_file = $self->_tempdir->child('jshint.json');
+    $conf_file->spew(
+        '{ ' . join( ",\n", map {qq["$_": true]} split /\s+/, $self->options ) . ' }' );
+    return "--config $conf_file";
+}
+
 1;
 
 # ABSTRACT: Use jshint with tidyall
@@ -63,7 +55,7 @@ Code::TidyAll::Plugin::JSHint - Use jshint with tidyall
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -128,7 +120,7 @@ config file and passed as --config to argv.
 
 =head1 SUPPORT
 
-bugs may be submitted through
+Bugs may be submitted through
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
@@ -147,7 +139,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
