@@ -4,7 +4,7 @@ use Pod::Checker;
 use Moo;
 extends 'Code::TidyAll::Plugin';
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 has 'warnings' => ( is => 'ro' );
 
@@ -16,7 +16,7 @@ sub validate_file {
     my $checker = Pod::Checker->new(%options);
     my $output;
     open my $fh, '>', \$output;
-    $checker->parse_from_file( $file, $fh );
+    $checker->parse_from_file( $file->stringify, $fh );
     die $output
         if $checker->num_errors > 0
         || ( $self->warnings && $checker->num_warnings > 0 );
@@ -38,7 +38,7 @@ Code::TidyAll::Plugin::PodChecker - Use podchecker with tidyall
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -78,7 +78,7 @@ ignored.
 
 =head1 SUPPORT
 
-bugs may be submitted through
+Bugs may be submitted through
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
@@ -97,7 +97,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
