@@ -2,22 +2,18 @@ package Code::TidyAll::Role::Tempdir;
 
 use Moo::Role;
 
-use Cwd qw(realpath);
-use File::Temp qw(tempdir);
+use Path::Tiny qw(tempdir);
 
-our $VERSION = '0.49';
+our $VERSION = '0.50';
 
 has '_tempdir'   => ( is => 'ro', lazy => 1, builder => 1 );
 has 'no_cleanup' => ( is => 'ro', default => 0 );
 
 sub _build__tempdir {
     my ($self) = @_;
-    return realpath(
-        tempdir(
-            'Code-TidyAll-XXXX',
-            TMPDIR  => 1,
-            CLEANUP => !$self->no_cleanup,
-        )
+    return tempdir(
+        'Code-TidyAll-XXXX',
+        CLEANUP => !$self->no_cleanup,
     );
 }
 
@@ -38,7 +34,7 @@ classes
 
 =head1 VERSION
 
-version 0.49
+version 0.50
 
 =head1 SYNOPSIS
 
@@ -67,7 +63,7 @@ should not automatically clean up after itself
 
 =head1 SUPPORT
 
-bugs may be submitted through
+Bugs may be submitted through
 L<https://github.com/houseabsolute/perl-code-tidyall/issues>.
 
 I am also usually active on IRC as 'drolsky' on C<irc://irc.perl.org>.
@@ -86,7 +82,7 @@ Dave Rolsky <autarch@urth.org>
 
 =back
 
-=head1 COPYRIGHT AND LICENCE
+=head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 - 2016 by Jonathan Swartz.
 
